@@ -21,12 +21,14 @@ pub struct Config {
 #[derive(Debug, Deserialize)]
 pub struct RssplsConfig {
     pub output: Option<String>,
+    pub proxy: Option<String>,
 }
 
 #[derive(Debug, Deserialize)]
 pub struct ChannelConfig {
     pub title: String,
     pub filename: String,
+    pub user_agent: Option<String>,
     pub config: FeedConfig,
 }
 
@@ -40,6 +42,7 @@ pub struct FeedConfig {
     pub summary: Option<String>,
     #[serde(default, deserialize_with = "opt_string_or_struct")]
     pub date: Option<DateConfig>,
+    pub media: Option<String>,
 }
 
 #[derive(Debug, Default, Deserialize)]
@@ -51,18 +54,13 @@ pub struct DateConfig {
     pub format: Option<OwnedFormatItem>,
 }
 
-#[derive(Debug, Deserialize, Copy, Clone)]
+#[derive(Debug, Default, Deserialize, Copy, Clone)]
 enum DateType {
     Date,
+    #[default]
     DateTime,
 }
 
-impl Default for DateType {
-    fn default() -> Self {
-        DateType::DateTime
-    }
-}
-
 impl Config {
     /// Read the config file path and the supplied path or default if None
     pub fn read(config_path: Option<PathBuf>) -> eyre::Result<Config> {
